pub struct Commitments(_);
Commitments made by the prover during commit phase of the protocol.

These commitments include:

  • Commitment to the extended execution trace, which may include commitments to one or more execution trace segments.
  • Commitment to the evaluations of constraint composition polynomial over LDE domain.
  • Commitments to the evaluations of polynomials at all FRI layers.

Internally, the commitments are stored as a sequence of bytes. Thus, to retrieve the commitments, parse() function should be used.

Implementations

Returns a new Commitments struct initialized with the provided commitments.

Adds the specified commitment to the list of commitments.

Parses the serialized commitments into distinct parts.

The parts are (in the order in which they appear in the tuple):

  1. Extended execution trace commitments.
  2. Constraint composition polynomial evaluation commitment.
  3. FRI layer commitments.
Errors

Returns an error if the bytes stored in self could not be parsed into the requested number of commitments, or if there are any unconsumed bytes remaining after the parsing completes.