Struct winter_air::proof::Commitments
source · pub struct Commitments(_);Expand description
Commitments made by the prover during commit phase of the protocol.
These commitments include:
- Commitment to the extended execution trace, which may include commitments to one or more execution trace segments.
- Commitment to the evaluations of constraint composition polynomial over LDE domain.
- Commitments to the evaluations of polynomials at all FRI layers.
Internally, the commitments are stored as a sequence of bytes. Thus, to retrieve the commitments, parse() function should be used.
Implementations
sourceimpl Commitments
impl Commitments
sourcepub fn new<H: Hasher>(
trace_roots: Vec<H::Digest>,
constraint_root: H::Digest,
fri_roots: Vec<H::Digest>
) -> Self
pub fn new<H: Hasher>(
trace_roots: Vec<H::Digest>,
constraint_root: H::Digest,
fri_roots: Vec<H::Digest>
) -> Self
Returns a new Commitments struct initialized with the provided commitments.
sourcepub fn add<H: Hasher>(&mut self, commitment: &H::Digest)
pub fn add<H: Hasher>(&mut self, commitment: &H::Digest)
Adds the specified commitment to the list of commitments.
sourcepub fn parse<H: Hasher>(
self,
num_trace_segments: usize,
num_fri_layers: usize
) -> Result<(Vec<H::Digest>, H::Digest, Vec<H::Digest>), DeserializationError>
pub fn parse<H: Hasher>(
self,
num_trace_segments: usize,
num_fri_layers: usize
) -> Result<(Vec<H::Digest>, H::Digest, Vec<H::Digest>), DeserializationError>
Parses the serialized commitments into distinct parts.
The parts are (in the order in which they appear in the tuple):
- Extended execution trace commitments.
- Constraint composition polynomial evaluation commitment.
- FRI layer commitments.
Errors
Returns an error if the bytes stored in self could not be parsed into the requested number of commitments, or if there are any unconsumed bytes remaining after the parsing completes.